leap Package
============

:mod:`leap` Package
-------------------

.. automodule:: leap.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_version` Module
----------------------

.. automodule:: leap._version
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app` Module
-----------------

.. automodule:: leap.app
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    leap.config
    leap.crypto
    leap.gui
    leap.keymanager
    leap.platform_init
    leap.services
    leap.util

